@@ -2,6 +2,7 @@ import os
 import json
 
 from .person import Person
+from .service import Service, Mailbox
 from .verbose import VERBOSE
 
 service_map = {
@@ -19,9 +20,14 @@ class User():
     def __init__(self, conn, data):
         self.conn = conn
         self.data = data
+        self.username = None
+        self.npid = None
         if data:
             for key in data:
                 setattr(self, key, data[key])
+                
+    def __getitem__(self, key):
+        return getattr(self, key, self.data.get(key))
 
     def delete(self):
         endpoint = '/usermgr/person/{}'.format(self.username)
@@ -39,6 +45,8 @@ class User():
         data = json.loads(resp.content.decode())
         if resp.ok:
             return Person(conn=self, data=data)
+        elif resp.status_code == 401:
+            raise ValueError('Provided admin-username/password is incorrect or you are not allowed to do this operation')
         else:
             raise ValueError(data['message'])
 
@@ -49,6 +57,8 @@ class User():
         if resp.ok:
             if VERBOSE:
                 print(mess.format(self.username, group_name))
+        elif resp.status_code == 401:
+            raise ValueError('Provided admin-username/password is incorrect or you are not allowed to do this operation')
         else:
             data = json.loads(resp.content.decode())
             raise ValueError(data['message'])
@@ -71,6 +81,8 @@ class User():
             if VERBOSE:
                 print("Service {} granted to {}".format(
                     service_name, self.username))
+        elif resp.status_code == 401:
+            raise ValueError('Provided admin-username/password is incorrect or you are not allowed to do this operation')
         else:
             data = json.loads(resp.content.decode())
             raise ValueError(data['message'])
@@ -85,18 +97,28 @@ class User():
             if VERBOSE:
                 print("Service {} revoked from {}".format(
                     service_name, self.username))
+        elif resp.status_code == 401:
+            raise ValueError('Provided admin-username/password is incorrect or you are not allowed to do this operation')
         else:
             data = json.loads(resp.content.decode())
             raise ValueError(data['message'])
 
     def get_service(self, service_name):
-        # TODO: API is not implemented yet
+        clean_service_name = service_map.get(service_name.upper())
+        if not clean_service_name:
+            raise ValueError(f"No such service: {service_name}")
+        service_name=clean_service_name
         endpoint = '/usermgr/user/{}/service/{}'.format(
             self.username, service_name)
         resp = self.conn._get_request(endpoint)
         data = json.loads(resp.content.decode())
         if resp.ok:
-            return Service(conn=self.conn, data=data)
+            if service_name == 'Mailbox':
+                return Mailbox(conn=self.conn, username=self.username, service_name=service_name, data=data)
+            else:
+                return Service(conn=self.conn, username=self.username, service_name=service_name, data=data)
+        elif resp.status_code == 401:
+            raise ValueError('Provided admin-username/password is incorrect or you are not allowed to do this operation')
         else:
             raise ValueError(data['message'])
 
@@ -120,6 +142,8 @@ class User():
                         self.username, service_name
                     )
                 )
+        elif resp.status_code == 401:
+            raise ValueError('Provided admin-username/password is incorrect or you are not allowed to do this operation')
         else:
             data = json.loads(resp.content.decode())
             raise ValueError(f"Error: could not set the password for user {self.username} and service {service_name}.\nMessage: {data['message']}")
